==> mariadb-10.6_10.6.7.orig.tar.gz: mariadb-10.6-10.6.7/storage/columnstore/columnstore/utils/regr/regr_r2.h <==
/* Copyright (C) 2017 MariaDB Corporation

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; version 2 of
   the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA. */

/***********************************************************************
*   $Id$
*
*   regr_r2.h
***********************************************************************/

/**
 * Columnstore interface for for the regr_r2 function
 *
 *
 *    CREATE AGGREGATE FUNCTION regr_r2 returns REAL soname 'libregr_mysql.so';
 *
 */
#ifndef HEADER_regr_r2
#define HEADER_regr_r2

#include <cstdlib>
#include <string>
#include <vector>
#ifdef _MSC_VER
#include <unordered_map>
#else
#include <tr1/unordered_map>
#endif

#include "mcsv1_udaf.h"
#include "calpontsystemcatalog.h"
#include "windowfunctioncolumn.h"

#if defined(_MSC_VER) && defined(xxxRGNODE_DLLEXPORT)
#define EXPORT __declspec(dllexport)
#else
#define EXPORT
#endif

namespace mcsv1sdk
{

// Return the regr_r2 value of the dataset

class regr_r2 : public  mcsv1_UDAF
{
public:
    // Defaults OK
    regr_r2() : mcsv1_UDAF() {};
    virtual ~regr_r2() {};

    virtual ReturnCode init(mcsv1Context* context,
                            ColumnDatum* colTypes);

    virtual ReturnCode reset(mcsv1Context* context);

    virtual ReturnCode nextValue(mcsv1Context* context, ColumnDatum* valsIn);

    virtual ReturnCode subEvaluate(mcsv1Context* context, const UserData* valIn);

    virtual ReturnCode evaluate(mcsv1Context* context, static_any::any& valOut);

    virtual ReturnCode dropValue(mcsv1Context* context, ColumnDatum* valsDropped);

protected:
};

};  // namespace

#undef EXPORT

#endif // HEADER_regr_r2.h

==> mariadb_11.8.3.orig.tar.gz: mariadb-11.8.3/storage/columnstore/columnstore/utils/regr/regr_r2.h <==
/* Copyright (C) 2017 MariaDB Corporation

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; version 2 of
   the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA. */

/***********************************************************************
 *   $Id$
 *
 *   regr_r2.h
 ***********************************************************************/

/**
 * Columnstore interface for for the regr_r2 function
 *
 *
 *    CREATE AGGREGATE FUNCTION regr_r2 returns REAL soname 'libregr_mysql.so';
 *
 */
#pragma once

#include <cstdlib>
#include <string>
#include <vector>
#include <tr1/unordered_map>

#include "mcsv1_udaf.h"
#include "calpontsystemcatalog.h"
#include "windowfunctioncolumn.h"

#define EXPORT

namespace mcsv1sdk
{
// Return the regr_r2 value of the dataset

class regr_r2 : public mcsv1_UDAF
{
 public:
  // Defaults OK
  regr_r2() : mcsv1_UDAF(){};
  ~regr_r2() override = default;

  ReturnCode init(mcsv1Context* context, ColumnDatum* colTypes) override;

  ReturnCode reset(mcsv1Context* context) override;

  ReturnCode nextValue(mcsv1Context* context, ColumnDatum* valsIn) override;

  ReturnCode subEvaluate(mcsv1Context* context, const UserData* valIn) override;

  ReturnCode evaluate(mcsv1Context* context, static_any::any& valOut) override;

  ReturnCode dropValue(mcsv1Context* context, ColumnDatum* valsDropped) override;

 protected:
};

};  // namespace mcsv1sdk

#undef EXPORT
